@@ -6,6 +6,8 @@
 
 #pragma once
 
+// IWYU pragma: private, include "CLI/CLI.hpp"
+
 // [CLI11:public_includes:set]
 #include <algorithm>
 #include <string>
@@ -21,5 +23,5 @@ namespace CLI {
 }  // namespace CLI
 
 #ifndef CLI11_COMPILE
-#include "impl/Formatter_inl.hpp"
+#include "impl/Formatter_inl.hpp"  // IWYU pragma: export
 #endif
