@@ -6,7 +6,7 @@
  *
  * This file is part of osm2pgsql (https://osm2pgsql.org/).
  *
- * Copyright (C) 2006-2024 by the osm2pgsql developer community.
+ * Copyright (C) 2006-2025 by the osm2pgsql developer community.
  * For a full list of authors see the git log.
  */
 
@@ -101,6 +101,11 @@ protected:
 
     pg_result_t dbexec(params_t const &tmp_params, std::string const &templ);
 
+    void dbprepare(std::string_view stmt, std::string const &templ);
+
+    void dbprepare(std::string_view stmt, params_t const &tmp_params,
+                   std::string const &templ);
+
     void raster_table_preprocess(std::string const &table);
 
     void raster_table_postprocess(std::string const &table);
