@@ -3,7 +3,7 @@
  *
  * This file is part of osm2pgsql (https://osm2pgsql.org/).
  *
- * Copyright (C) 2006-2024 by the osm2pgsql developer community.
+ * Copyright (C) 2006-2025 by the osm2pgsql developer community.
  * For a full list of authors see the git log.
  */
 
@@ -121,9 +121,9 @@ void properties_t::store()
 
     pg_conn_t const db_connection{m_connection_params, "prop.store"};
 
-    db_connection.exec(
-        "PREPARE set_property(text, text) AS"
-        " INSERT INTO {} (property, value) VALUES ($1, $2)"
+    db_connection.prepare(
+        "set_property",
+        "INSERT INTO {} (property, value) VALUES ($1::text, $2::text)"
         " ON CONFLICT (property) DO UPDATE SET value = EXCLUDED.value",
         table);
 
