@@ -15,34 +15,21 @@ class generic_reprojection_t : public reprojection
 {
 public:
     explicit generic_reprojection_t(int srs)
-    : m_target_srs(srs), m_context(proj_context_create())
+    : m_target_srs(srs), m_context(proj_context_create()),
+      m_transformation(create_transformation(PROJ_LATLONG, srs)),
+      m_transformation_tile(create_transformation(srs, PROJ_SPHERE_MERC))
+    {}
+
+    geom::point_t
+    reproject(geom::point_t point) const noexcept override
     {
-        assert(m_context);
-
-        m_transformation = create_transformation(PROJ_LATLONG, srs);
-
-        m_transformation.reset(proj_normalize_for_visualization(
-            m_context.get(), m_transformation.get()));
-
-        if (!m_transformation) {
-            throw std::runtime_error{
-                "Invalid projection '{}': {}"_format(srs, errormsg())};
-        }
-
-        m_transformation_tile = create_transformation(PROJ_SPHERE_MERC, srs);
+        return transform(m_transformation.get(), point);
     }
 
-    osmium::geom::Coordinates reproject(osmium::Location loc) const override
+    geom::point_t
+    target_to_tile(geom::point_t point) const override
     {
-        return transform(m_transformation.get(),
-                         osmium::geom::Coordinates{loc.lon_without_check(),
-                                                   loc.lat_without_check()});
-    }
-
-    osmium::geom::Coordinates
-    target_to_tile(osmium::geom::Coordinates coords) const override
-    {
-        return transform(m_transformation_tile.get(), coords);
+        return transform(m_transformation_tile.get(), point);
     }
 
     int target_srs() const noexcept override { return m_target_srs; }
@@ -71,34 +58,43 @@ private:
     std::unique_ptr<PJ, pj_deleter_t> create_transformation(int from,
                                                             int to) const
     {
-        std::string const source = "epsg:{}"_format(from);
-        std::string const target = "epsg:{}"_format(to);
+        assert(m_context);
 
-        std::unique_ptr<PJ, pj_deleter_t> trans{proj_create_crs_to_crs(
+        std::string const source = fmt::format("epsg:{}", from);
+        std::string const target = fmt::format("epsg:{}", to);
+
+        std::unique_ptr<PJ, pj_deleter_t> const trans{proj_create_crs_to_crs(
             m_context.get(), source.c_str(), target.c_str(), nullptr)};
 
         if (!trans) {
-            throw std::runtime_error{
-                "Invalid projection from {} to {}: {}"_format(from, to,
-                                                              errormsg())};
+            throw fmt_error("Invalid projection from {} to {}: {}", from, to,
+                            errormsg());
         }
-        return trans;
+
+        std::unique_ptr<PJ, pj_deleter_t> trans_vis{
+            proj_normalize_for_visualization(m_context.get(), trans.get())};
+
+        if (!trans_vis) {
+            throw fmt_error("Invalid projection from {} to {}: {}", from, to,
+                            errormsg());
+        }
+
+        return trans_vis;
     }
 
-    osmium::geom::Coordinates transform(PJ *transformation,
-                                        osmium::geom::Coordinates coords) const
-        noexcept
+    static geom::point_t transform(PJ *transformation,
+                                   geom::point_t point) noexcept
     {
         PJ_COORD c_in;
         c_in.lpzt.z = 0.0;
         c_in.lpzt.t = HUGE_VAL;
-        c_in.lpzt.lam = osmium::geom::deg_to_rad(coords.x);
-        c_in.lpzt.phi = osmium::geom::deg_to_rad(coords.y);
+        c_in.lpzt.lam = point.x();
+        c_in.lpzt.phi = point.y();
 
         auto const c_out = proj_trans(transformation, PJ_FWD, c_in);
 
         // NOLINTNEXTLINE(cppcoreguidelines-pro-type-union-access)
-        return osmium::geom::Coordinates{c_out.xy.x, c_out.xy.y};
+        return {c_out.xy.x, c_out.xy.y};
     }
 
     int m_target_srs;
@@ -123,6 +119,6 @@ std::shared_ptr<reprojection> reprojection::make_generic_projection(int srs)
 
 std::string get_proj_version()
 {
-    return "[API 6] {}"_format(proj_info().version);
+    return fmt::format("{}", proj_info().version);
 }
 
